@@ -313,7 +313,7 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	label = gtk_label_new_with_mnemonic (_(title));
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
 	gtk_box_pack_start (GTK_BOX (category_vbox), label, FALSE, FALSE, 0);
 	g_free (title);
 	
@@ -418,7 +418,7 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	label = gtk_label_new (title);
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
 	gtk_box_pack_start (GTK_BOX (category_vbox), label, FALSE, FALSE, 0);
 	gtk_widget_show (label);
 	g_free (title);
@@ -449,7 +449,7 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 		label_text = g_strdup(_("System m_onitor height: "));
 	
 	label = gtk_label_new_with_mnemonic(label_text);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
+	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
 	gtk_size_group_add_widget (label_size, label);
         gtk_box_pack_start (GTK_BOX (control_hbox), label, FALSE, FALSE, 0);
 	
@@ -478,7 +478,7 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	gtk_box_pack_start (GTK_BOX (hbox), spin_button, FALSE, FALSE, 0);
 	
 	label = gtk_label_new (_("pixels"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
+	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	
 	control_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
@@ -486,7 +486,7 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	gtk_widget_show (control_hbox);
 	
 	label = gtk_label_new_with_mnemonic(_("Sys_tem monitor update interval: "));
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
+	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
 	gtk_size_group_add_widget (label_size, label);
 	gtk_box_pack_start (GTK_BOX (control_hbox), label, FALSE, FALSE, 0);
 	
@@ -512,7 +512,7 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	}
 	
 	label = gtk_label_new(_("milliseconds"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
+	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	
 	g_free(label_text);
@@ -526,7 +526,7 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	label = gtk_label_new (title);
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
 	gtk_box_pack_start (GTK_BOX (category_vbox), label, FALSE, FALSE, 0);
 	gtk_widget_show (label);
 	g_free (title);
