@@ -31,11 +31,52 @@
 
 /* Stop gcc complaining about xmlChar's signedness */
 #define XML_CHAR(str) ((xmlChar *) (str))
+#define XML_PATH	"/.config/gnome-applets/stickynotes"
+#define STICKYNOTES_ICON_SIZE 8
 
 static gboolean save_scheduled = FALSE;
 
 static void response_cb (GtkWidget *dialog, gint id, gpointer data);
 
+/* Popup menu on the sticky note */
+static const GActionEntry stickynotes_note_menu_actions [] = {
+	{ "create",     popup_create_cb,      NULL, NULL,    NULL },
+	{ "lock",       popup_toggle_lock_cb, NULL, "false", popup_toggle_lock_state },
+	{ "destroy",    popup_destroy_cb,     NULL, NULL,    NULL },
+	{ "properties", popup_properties_cb,  NULL, NULL,    NULL }
+};
+
+static void
+setup_note_menu (StickyNote *note)
+{
+	GSimpleActionGroup *action_group;
+	gchar *ui_file;
+	GtkBuilder *builder;
+	GMenu *gmenu;
+
+	action_group = g_simple_action_group_new ();
+	g_action_map_add_action_entries (G_ACTION_MAP (action_group),
+	                                 stickynotes_note_menu_actions,
+	                                 G_N_ELEMENTS (stickynotes_note_menu_actions),
+	                                 note);
+
+	ui_file = g_build_filename (STICKYNOTES_MENU_UI_DIR, "stickynotes-note-menu.xml", NULL);
+	builder = gtk_builder_new_from_file (ui_file);
+	g_free (ui_file);
+
+	gtk_builder_set_translation_domain (builder, GETTEXT_PACKAGE);
+
+	gmenu = G_MENU (gtk_builder_get_object (builder, "note-popup"));
+	note->w_menu = gtk_menu_new_from_model (G_MENU_MODEL (gmenu));
+	g_object_unref (builder);
+
+	gtk_menu_attach_to_widget (GTK_MENU (note->w_menu), GTK_WIDGET (note->w_window), NULL);
+
+	gtk_widget_insert_action_group (GTK_WIDGET (note->w_window), "stickynote",
+	                                G_ACTION_GROUP (action_group));
+	g_object_unref (action_group);
+}
+
 /* Based on a function found in wnck */
 static void
 set_icon_geometry  (GdkWindow *window,
@@ -95,12 +136,12 @@ stickynote_new_aux (GdkScreen *screen, gint x, gint y, gint w, gint h)
 {
 	StickyNote *note;
 	GtkBuilder *builder;
-	GtkIconSize size;
 
 	note = g_new (StickyNote, 1);
 
 	builder = gtk_builder_new ();
-	gtk_builder_add_from_file (builder, BUILDER_PATH, NULL);
+	gtk_builder_add_from_file (builder, GTK_BUILDERDIR "/stickynotes-note.ui", NULL);
+	gtk_builder_add_from_file (builder, GTK_BUILDERDIR "/stickynotes-properties.ui", NULL);
 
 	note->w_window = GTK_WIDGET (gtk_builder_get_object (builder, "stickynote_window"));
 	gtk_window_set_screen(GTK_WINDOW(note->w_window),screen);
@@ -135,9 +176,7 @@ stickynote_new_aux (GdkScreen *screen, gint x, gint y, gint w, gint h)
 	gtk_widget_set_direction (GTK_WIDGET (gtk_builder_get_object (builder, "resize_bar")),
 			GTK_TEXT_DIR_LTR);
 
-	note->w_menu = GTK_WIDGET (gtk_builder_get_object (builder, "stickynote_menu"));
-	note->ta_lock_toggle_item = GTK_TOGGLE_ACTION (gtk_builder_get_object (builder,
-	        "popup_toggle_lock"));
+	setup_note_menu (note);
 
 	note->w_properties = GTK_WIDGET (gtk_builder_get_object (builder,
 			"stickynote_properties"));
@@ -186,13 +225,15 @@ stickynote_new_aux (GdkScreen *screen, gint x, gint y, gint w, gint h)
 				note->y);
 
 	/* Set the button images */
-	size = gtk_icon_size_from_name ("stickynotes_icon_size");
-	gtk_image_set_from_stock (note->img_close,
-			STICKYNOTES_STOCK_CLOSE, size);
-	gtk_image_set_from_stock (note->img_resize_se,
-			STICKYNOTES_STOCK_RESIZE_SE, size);
-	gtk_image_set_from_stock (note->img_resize_sw,
-			STICKYNOTES_STOCK_RESIZE_SW, size);
+	gtk_image_set_from_icon_name (note->img_close, STICKYNOTES_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
+	gtk_image_set_pixel_size (note->img_close, STICKYNOTES_ICON_SIZE);
+
+	gtk_image_set_from_icon_name (note->img_resize_se, STICKYNOTES_STOCK_RESIZE_SE, GTK_ICON_SIZE_MENU);
+	gtk_image_set_pixel_size (note->img_resize_se, STICKYNOTES_ICON_SIZE);
+
+	gtk_image_set_from_icon_name (note->img_resize_sw, STICKYNOTES_STOCK_RESIZE_SW, GTK_ICON_SIZE_MENU);
+	gtk_image_set_pixel_size (note->img_resize_sw, STICKYNOTES_ICON_SIZE);
+
 	gtk_widget_show(note->w_lock);
 	gtk_widget_show(note->w_close);
 	gtk_widget_show(GTK_WIDGET (gtk_builder_get_object (builder, "resize_bar")));
@@ -205,12 +246,6 @@ stickynote_new_aux (GdkScreen *screen, gint x, gint y, gint w, gint h)
 
 	gtk_widget_realize (note->w_window);
 
-	/* Connect a popup menu to all buttons and title */
-	/* GtkBuilder holds and drops the references to all the widgets it
-	 * creates for as long as it exist (GtkBuilder). Hence in our callback
-	 * we would have an invalid GtkMenu. We need to ref it.
-	 */
-	g_object_ref (note->w_menu);
 	g_signal_connect (G_OBJECT (note->w_window), "button-press-event",
 			G_CALLBACK (stickynote_show_popup_menu), note->w_menu);
 
@@ -246,26 +281,11 @@ stickynote_new_aux (GdkScreen *screen, gint x, gint y, gint w, gint h)
 
 	g_signal_connect (G_OBJECT (note->w_window), "button-press-event",
 			G_CALLBACK (stickynote_move_cb), note);
-	g_signal_connect (G_OBJECT (note->w_window), "expose-event",
-			G_CALLBACK (stickynote_expose_cb), note);
 	g_signal_connect (G_OBJECT (note->w_window), "configure-event",
 			G_CALLBACK (stickynote_configure_cb), note);
 	g_signal_connect (G_OBJECT (note->w_window), "delete-event",
 			G_CALLBACK (stickynote_delete_cb), note);
 
-	g_signal_connect (gtk_builder_get_object (builder,
-					"popup_create"), "activate",
-			G_CALLBACK (popup_create_cb), note);
-	g_signal_connect (gtk_builder_get_object (builder,
-					"popup_destroy"), "activate",
-			G_CALLBACK (popup_destroy_cb), note);
-	g_signal_connect (gtk_builder_get_object (builder,
-					"popup_toggle_lock"), "toggled",
-			G_CALLBACK (popup_toggle_lock_cb), note);
-	g_signal_connect (gtk_builder_get_object (builder,
-					"popup_properties"), "activate",
-			G_CALLBACK (popup_properties_cb), note);
-
 	g_signal_connect_swapped (G_OBJECT (note->w_entry), "changed",
 			G_CALLBACK (properties_apply_title_cb), note);
 	g_signal_connect (G_OBJECT (note->w_color), "color-set",
@@ -335,7 +355,7 @@ void stickynote_change_properties (StickyNote *note)
 	{
 		gdk_rgba_parse (&color, color_str);
 		g_free (color_str);
-		gtk_color_button_set_rgba (GTK_COLOR_BUTTON (note->w_color), &color);
+		gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (note->w_color), &color);
 	}
 
 	if (note->font_color)
@@ -349,7 +369,7 @@ void stickynote_change_properties (StickyNote *note)
 	{
 		gdk_rgba_parse (&font_color, color_str);
 		g_free (color_str);
-		gtk_color_button_set_rgba (GTK_COLOR_BUTTON (note->w_font_color), &font_color);
+		gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (note->w_font_color), &font_color);
 	}
 
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(note->w_def_font),
@@ -602,28 +622,27 @@ stickynote_set_font (StickyNote *note, const gchar *font_str, gboolean save)
 }
 
 /* Lock/Unlock a sticky note from editing */
-void stickynote_set_locked(StickyNote *note, gboolean locked)
+void
+stickynote_set_locked (StickyNote *note,
+                       gboolean    locked)
 {
-	GtkIconSize size;
 	note->locked = locked;
 
 	/* Set cursor visibility and editability */
 	gtk_text_view_set_editable(GTK_TEXT_VIEW(note->w_body), !locked);
 	gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(note->w_body), !locked);
 
-	size = gtk_icon_size_from_name ("stickynotes_icon_size");
-
 	/* Show appropriate icon and tooltip */
 	if (locked) {
-		gtk_image_set_from_stock(note->img_lock, STICKYNOTES_STOCK_LOCKED, size);
+		gtk_image_set_from_icon_name (note->img_lock, STICKYNOTES_STOCK_LOCKED, GTK_ICON_SIZE_MENU);
 		gtk_widget_set_tooltip_text(note->w_lock, _("This note is locked."));
 	}
 	else {
-		gtk_image_set_from_stock(note->img_lock, STICKYNOTES_STOCK_UNLOCKED, size);
+		gtk_image_set_from_icon_name (note->img_lock, STICKYNOTES_STOCK_UNLOCKED, GTK_ICON_SIZE_MENU);
 		gtk_widget_set_tooltip_text(note->w_lock, _("This note is unlocked."));
 	}
 
-	gtk_toggle_action_set_active(note->ta_lock_toggle_item, locked);
+	gtk_image_set_pixel_size (note->img_lock, STICKYNOTES_ICON_SIZE);
 
 	stickynotes_applet_update_menus();
 }
@@ -699,7 +718,7 @@ void stickynotes_remove(StickyNote *note)
 	GtkWidget *dialog;
 
 	builder = gtk_builder_new ();
-	gtk_builder_add_from_file (builder, BUILDER_PATH, NULL);
+	gtk_builder_add_from_file (builder, GTK_BUILDERDIR "/stickynotes-delete.ui", NULL);
 
 	dialog = GTK_WIDGET (gtk_builder_get_object (builder, "delete_dialog"));
 
